@@ -15,19 +15,17 @@
 
 from unittest import mock
 
-import six
-
 from sahara.plugins import base as pb
-from sahara_plugin_cdh.plugins.cdh.v5_7_0 import edp_engine
-from sahara_plugin_cdh.plugins.cdh.v5_7_0 import versionhandler
+from sahara_plugin_cdh.plugins.cdh.v5_9_0 import edp_engine
+from sahara_plugin_cdh.plugins.cdh.v5_9_0 import versionhandler
 from sahara_plugin_cdh.tests.unit import base
 
 
 class VersionHandlerTestCase(base.SaharaTestCase):
 
-    plugin_path = "sahara_plugin_cdh.plugins.cdh.v5_7_0."
-    cloudera_utils_path = plugin_path + "cloudera_utils.ClouderaUtilsV570."
-    plugin_utils_path = plugin_path + "plugin_utils.PluginUtilsV570."
+    plugin_path = "sahara_plugin_cdh.plugins.cdh.v5_9_0."
+    cloudera_utils_path = plugin_path + "cloudera_utils.ClouderaUtilsV590."
+    plugin_utils_path = plugin_path + "plugin_utils.PluginUtilsV590."
 
     def setUp(self):
         super(VersionHandlerTestCase, self).setUp()
@@ -37,7 +35,7 @@ class VersionHandlerTestCase(base.SaharaTestCase):
 
     def test_get_node_processes(self):
         processes = self.vh.get_node_processes()
-        for k, v in six.iteritems(processes):
+        for k, v in processes.items():
             for p in v:
                 self.assertIsInstance(p, str)
 
